Thiemo Kreuz (WMDE) has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/400582 )

Change subject: Remove @param comments that literally repeat what the code says
......................................................................

Remove @param comments that literally repeat what the code says

These comments do not add anything. I argue they are worse than having
no comments, because I have to read them first to understand they
actually don't explain anything. Removing them makes room for actual
improvements in the future (if needed).

Change-Id: Iee70aad681b3385e9af282d5581c10addbb91ac4
---
M includes/EditPage.php
M includes/FeedUtils.php
M includes/GlobalFunctions.php
M includes/Linker.php
M includes/OutputPage.php
M includes/Preferences.php
M includes/WebRequest.php
M includes/actions/HistoryAction.php
M includes/actions/InfoAction.php
M includes/api/ApiBase.php
M includes/api/ApiPageSet.php
M includes/auth/LegacyHookPreAuthenticationProvider.php
M includes/cache/CacheDependency.php
M includes/cache/GenderCache.php
M includes/cache/MessageCache.php
M includes/changes/ChangesListBooleanFilterGroup.php
M includes/changes/ChangesListFilter.php
M includes/changes/ChangesListFilterGroup.php
M includes/changes/ChangesListStringOptionsFilterGroup.php
M includes/changetags/ChangeTags.php
M includes/content/AbstractContent.php
M includes/content/JsonContent.php
M includes/content/TextContent.php
M includes/exception/LocalizedException.php
M includes/gallery/ImageGalleryBase.php
M includes/installer/PostgresInstaller.php
M includes/libs/IEUrlExtension.php
M includes/libs/StatusValue.php
M includes/libs/mime/XmlTypeCheck.php
M includes/libs/objectcache/MemcachedClient.php
M includes/libs/rdbms/TransactionProfiler.php
M includes/logging/LogEventsList.php
M includes/logging/LogPage.php
M includes/media/BitmapMetadataHandler.php
M includes/media/IPTC.php
M includes/media/MediaHandler.php
M includes/media/WebP.php
M includes/media/XCF.php
M includes/parser/Parser.php
M includes/parser/StripState.php
M includes/resourceloader/ResourceLoaderModule.php
M includes/revisiondelete/RevDelItem.php
M includes/search/SearchExactMatchRescorer.php
M includes/session/SessionBackend.php
M includes/specialpage/ChangesListSpecialPage.php
M includes/specials/SpecialRecentchanges.php
M includes/specials/SpecialUploadStash.php
M includes/specials/pagers/UsersPager.php
M includes/user/User.php
M maintenance/generateSitemap.php
M maintenance/importImages.php
M maintenance/sql.php
M tests/phpunit/includes/auth/LegacyHookPreAuthenticationProviderTest.php
M tests/phpunit/includes/collation/CollationTest.php
M tests/phpunit/includes/session/TestBagOStuff.php
M tests/phpunit/includes/session/TestUtils.php
M tests/phpunit/mocks/content/DummyContentForTesting.php
M tests/phpunit/mocks/content/DummyNonTextContent.php
58 files changed, 90 insertions(+), 94 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/82/400582/1

diff --git a/includes/EditPage.php b/includes/EditPage.php
index bcaab3a..6d64388 100644
--- a/includes/EditPage.php
+++ b/includes/EditPage.php
@@ -780,7 +780,7 @@
 
        /**
         * Display a read-only View Source page
-        * @param Content $content content object
+        * @param Content $content
         * @param string $errorMessage additional wikitext error message to 
display
         */
        protected function displayViewSourcePage( Content $content, 
$errorMessage = '' ) {
diff --git a/includes/FeedUtils.php b/includes/FeedUtils.php
index 6c343ab..6108ca1 100644
--- a/includes/FeedUtils.php
+++ b/includes/FeedUtils.php
@@ -97,7 +97,7 @@
        /**
         * Really format a diff for the newsfeed
         *
-        * @param Title $title Title object
+        * @param Title $title
         * @param int $oldid Old revision's id
         * @param int $newid New revision's id
         * @param int $timestamp New revision's timestamp
diff --git a/includes/GlobalFunctions.php b/includes/GlobalFunctions.php
index 1a33b76..7c5656d 100644
--- a/includes/GlobalFunctions.php
+++ b/includes/GlobalFunctions.php
@@ -1011,7 +1011,7 @@
 
 /**
  * Check whether a given URL has a domain that occurs in a given set of domains
- * @param string $url URL
+ * @param string $url
  * @param array $domains Array of domains (strings)
  * @return bool True if the host part of $url ends in one of the strings in 
$domains
  */
diff --git a/includes/Linker.php b/includes/Linker.php
index 84e3103..bda40af 100644
--- a/includes/Linker.php
+++ b/includes/Linker.php
@@ -1023,7 +1023,7 @@
 
        /**
         * @since 1.16.3
-        * @param int $userId Userid
+        * @param int $userId
         * @param string $userText User name in database.
         * @return string HTML fragment with block link
         */
@@ -1037,7 +1037,7 @@
        }
 
        /**
-        * @param int $userId Userid
+        * @param int $userId
         * @param string $userText User name in database.
         * @return string HTML fragment with e-mail user link
         */
diff --git a/includes/OutputPage.php b/includes/OutputPage.php
index 1c2c29d..05cf3da 100644
--- a/includes/OutputPage.php
+++ b/includes/OutputPage.php
@@ -323,7 +323,7 @@
        /**
         * Redirect to $url rather than displaying the normal page
         *
-        * @param string $url URL
+        * @param string $url
         * @param string $responsecode HTTP status code
         */
        public function redirect( $url, $responsecode = '302' ) {
diff --git a/includes/Preferences.php b/includes/Preferences.php
index 33a975d..06d5298 100644
--- a/includes/Preferences.php
+++ b/includes/Preferences.php
@@ -1164,7 +1164,7 @@
        }
 
        /**
-        * @param User $user The User object
+        * @param User $user
         * @param IContextSource $context
         * @return array Text/links to display as key; $skinkey as value
         */
diff --git a/includes/WebRequest.php b/includes/WebRequest.php
index 3d5e372..cd62737 100644
--- a/includes/WebRequest.php
+++ b/includes/WebRequest.php
@@ -407,7 +407,7 @@
         *
         * @since 1.28
         * @param string $name
-        * @param string|null $default Optional default
+        * @param string|null $default
         * @return string|null
         */
        public function getRawVal( $name, $default = null ) {
diff --git a/includes/actions/HistoryAction.php 
b/includes/actions/HistoryAction.php
index 85e8db6..f7ac21b 100644
--- a/includes/actions/HistoryAction.php
+++ b/includes/actions/HistoryAction.php
@@ -611,7 +611,7 @@
         * Creates a submit button
         *
         * @param string $message Text of the submit button, will be escaped
-        * @param array $attributes Attributes
+        * @param array $attributes
         * @return string HTML output for the submit button
         */
        function submitButton( $message, $attributes = [] ) {
diff --git a/includes/actions/InfoAction.php b/includes/actions/InfoAction.php
index 62f7ddf..cb01a9d 100644
--- a/includes/actions/InfoAction.php
+++ b/includes/actions/InfoAction.php
@@ -186,7 +186,7 @@
         * Adds a table to the content that will be added to the output.
         *
         * @param string $content The content that will be added to the output
-        * @param string $table The table
+        * @param string $table
         * @return string The content with the table added
         */
        protected function addTable( $content, $table ) {
diff --git a/includes/api/ApiBase.php b/includes/api/ApiBase.php
index 83d2ae9..3993be3 100644
--- a/includes/api/ApiBase.php
+++ b/includes/api/ApiBase.php
@@ -1029,7 +1029,7 @@
         * @param string $paramName Parameter name
         * @param array|mixed $paramSettings Default value or an array of 
settings
         *  using PARAM_* constants.
-        * @param bool $parseLimit Parse limit?
+        * @param bool $parseLimit
         * @return mixed Parameter value
         */
        protected function getParameterFromSettings( $paramName, 
$paramSettings, $parseLimit ) {
diff --git a/includes/api/ApiPageSet.php b/includes/api/ApiPageSet.php
index cfac761..774ea1a 100644
--- a/includes/api/ApiPageSet.php
+++ b/includes/api/ApiPageSet.php
@@ -753,7 +753,7 @@
         * $this->getPageTableFields().
         *
         * @param IDatabase $db
-        * @param ResultWrapper $queryResult Query result object
+        * @param ResultWrapper $queryResult
         */
        public function populateFromQueryResult( $db, $queryResult ) {
                $this->initFromQueryResult( $queryResult );
diff --git a/includes/auth/LegacyHookPreAuthenticationProvider.php 
b/includes/auth/LegacyHookPreAuthenticationProvider.php
index cab6e32..3129e9a 100644
--- a/includes/auth/LegacyHookPreAuthenticationProvider.php
+++ b/includes/auth/LegacyHookPreAuthenticationProvider.php
@@ -117,7 +117,7 @@
         * @param User|null $creator
         * @param int $constant LoginForm constant
         * @param string|null $msg Message
-        * @param string $hook Hook
+        * @param string $hook
         * @return StatusValue
         */
        protected function makeFailResponse( $user, $creator, $constant, $msg, 
$hook ) {
diff --git a/includes/cache/CacheDependency.php 
b/includes/cache/CacheDependency.php
index a59ba97..2c9d214 100644
--- a/includes/cache/CacheDependency.php
+++ b/includes/cache/CacheDependency.php
@@ -99,7 +99,7 @@
         * it will be generated with the callback function (if present), and 
the newly
         * calculated value will be stored to the cache in a wrapper.
         *
-        * @param BagOStuff $cache A cache object
+        * @param BagOStuff $cache
         * @param string $key The cache key
         * @param int $expiry The expiry timestamp or interval in seconds
         * @param bool|callable $callback The callback for generating the 
value, or false
diff --git a/includes/cache/GenderCache.php b/includes/cache/GenderCache.php
index a34d235..099a986 100644
--- a/includes/cache/GenderCache.php
+++ b/includes/cache/GenderCache.php
@@ -56,7 +56,7 @@
 
        /**
         * Returns the gender for given username.
-        * @param string|User $username Username
+        * @param string|User $username
         * @param string $caller The calling method
         * @return string
         */
diff --git a/includes/changes/ChangesListBooleanFilterGroup.php 
b/includes/changes/ChangesListBooleanFilterGroup.php
index 7bab97b..4401378 100644
--- a/includes/changes/ChangesListBooleanFilterGroup.php
+++ b/includes/changes/ChangesListBooleanFilterGroup.php
@@ -54,7 +54,7 @@
        /**
         * Registers a filter in this group
         *
-        * @param ChangesListBooleanFilter $filter ChangesListBooleanFilter
+        * @param ChangesListBooleanFilter $filter
         */
        public function registerFilter( ChangesListBooleanFilter $filter ) {
                $this->filters[$filter->getName()] = $filter;
diff --git a/includes/changes/ChangesListFilter.php 
b/includes/changes/ChangesListFilter.php
index 1c86d44..d1ecd84 100644
--- a/includes/changes/ChangesListFilter.php
+++ b/includes/changes/ChangesListFilter.php
@@ -184,8 +184,7 @@
         * (not filtered out), even for the hide-based filters.  So e.g. 
conflicting with
         * 'hideanons' means there is a conflict if only anonymous users are 
*shown*.
         *
-        * @param ChangesListFilterGroup|ChangesListFilter $other Other
-        *  ChangesListFilterGroup or ChangesListFilter
+        * @param ChangesListFilterGroup|ChangesListFilter $other
         * @param string $globalKey i18n key for top-level conflict message
         * @param string $forwardKey i18n key for conflict message in this
         *  direction (when in UI context of $this object)
@@ -216,8 +215,7 @@
         *
         * Internal use ONLY.
         *
-        * @param ChangesListFilterGroup|ChangesListFilter $other Other
-        *  ChangesListFilterGroup or ChangesListFilter
+        * @param ChangesListFilterGroup|ChangesListFilter $other
         * @param string $globalDescription i18n key for top-level conflict 
message
         * @param string $contextDescription i18n key for conflict message in 
this
         *  direction (when in UI context of $this object)
diff --git a/includes/changes/ChangesListFilterGroup.php 
b/includes/changes/ChangesListFilterGroup.php
index 48c6e84..f569dca 100644
--- a/includes/changes/ChangesListFilterGroup.php
+++ b/includes/changes/ChangesListFilterGroup.php
@@ -223,8 +223,7 @@
         * (not filtered out), even for the hide-based filters.  So e.g. 
conflicting with
         * 'hideanons' means there is a conflict if only anonymous users are 
*shown*.
         *
-        * @param ChangesListFilterGroup|ChangesListFilter $other Other
-        *  ChangesListFilterGroup or ChangesListFilter
+        * @param ChangesListFilterGroup|ChangesListFilter $other
         * @param string $globalKey i18n key for top-level conflict message
         * @param string $forwardKey i18n key for conflict message in this
         *  direction (when in UI context of $this object)
@@ -255,8 +254,7 @@
         *
         * Internal use ONLY.
         *
-        * @param ChangesListFilterGroup|ChangesListFilter $other Other
-        *  ChangesListFilterGroup or ChangesListFilter
+        * @param ChangesListFilterGroup|ChangesListFilter $other
         * @param string $globalDescription i18n key for top-level conflict 
message
         * @param string $contextDescription i18n key for conflict message in 
this
         *  direction (when in UI context of $this object)
diff --git a/includes/changes/ChangesListStringOptionsFilterGroup.php 
b/includes/changes/ChangesListStringOptionsFilterGroup.php
index 775fd76..1497a44 100644
--- a/includes/changes/ChangesListStringOptionsFilterGroup.php
+++ b/includes/changes/ChangesListStringOptionsFilterGroup.php
@@ -155,7 +155,7 @@
        /**
         * Registers a filter in this group
         *
-        * @param ChangesListStringOptionsFilter $filter 
ChangesListStringOptionsFilter
+        * @param ChangesListStringOptionsFilter $filter
         */
        public function registerFilter( ChangesListStringOptionsFilter $filter 
) {
                $this->filters[$filter->getName()] = $filter;
diff --git a/includes/changetags/ChangeTags.php 
b/includes/changetags/ChangeTags.php
index db1f599..95848ea 100644
--- a/includes/changetags/ChangeTags.php
+++ b/includes/changetags/ChangeTags.php
@@ -135,7 +135,7 @@
         * exists, provided it is not disabled. If the message is disabled,
         * we consider the tag hidden, and return false.
         *
-        * @param string $tag Tag
+        * @param string $tag
         * @param IContextSource $context
         * @return string|bool Tag description or false if tag is to be hidden.
         * @since 1.25 Returns false if tag is to be hidden.
@@ -162,7 +162,7 @@
         * or if message is disabled, returns false. Otherwise, returns the 
message object
         * for the long description.
         *
-        * @param string $tag Tag
+        * @param string $tag
         * @param IContextSource $context
         * @return Message|bool Message object of the tag long description or 
false if
         *  there is no description.
diff --git a/includes/content/AbstractContent.php 
b/includes/content/AbstractContent.php
index c12d28d..65dc3bb 100644
--- a/includes/content/AbstractContent.php
+++ b/includes/content/AbstractContent.php
@@ -492,7 +492,7 @@
         *
         * @param Title $title Context title for parsing
         * @param int|null $revId Revision ID (for {{REVISIONID}})
-        * @param ParserOptions|null $options Parser options
+        * @param ParserOptions|null $options
         * @param bool $generateHtml Whether or not to generate HTML
         *
         * @return ParserOutput Containing information derived from this 
content.
@@ -536,7 +536,7 @@
         *
         * @param Title $title Context title for parsing
         * @param int|null $revId Revision ID (for {{REVISIONID}})
-        * @param ParserOptions $options Parser options
+        * @param ParserOptions $options
         * @param bool $generateHtml Whether or not to generate HTML
         * @param ParserOutput &$output The output object to fill (reference).
         *
diff --git a/includes/content/JsonContent.php b/includes/content/JsonContent.php
index 2b94f3f..7d8f67c 100644
--- a/includes/content/JsonContent.php
+++ b/includes/content/JsonContent.php
@@ -75,8 +75,8 @@
        /**
         * Beautifies JSON prior to save.
         *
-        * @param Title $title Title
-        * @param User $user User
+        * @param Title $title
+        * @param User $user
         * @param ParserOptions $popts
         * @return JsonContent
         */
diff --git a/includes/content/TextContent.php b/includes/content/TextContent.php
index e5a9f90..71f65b3 100644
--- a/includes/content/TextContent.php
+++ b/includes/content/TextContent.php
@@ -236,7 +236,7 @@
         *
         * @param Title $title Context title for parsing
         * @param int $revId Revision ID (for {{REVISIONID}})
-        * @param ParserOptions $options Parser options
+        * @param ParserOptions $options
         * @param bool $generateHtml Whether or not to generate HTML
         * @param ParserOutput &$output The output object to fill (reference).
         */
diff --git a/includes/exception/LocalizedException.php 
b/includes/exception/LocalizedException.php
index d2cb5d1..f5f8c84 100644
--- a/includes/exception/LocalizedException.php
+++ b/includes/exception/LocalizedException.php
@@ -45,7 +45,7 @@
 
        /**
         * @param string|array|MessageSpecifier $messageSpec See 
Message::newFromSpecifier
-        * @param int $code Exception code
+        * @param int $code
         * @param Exception|Throwable $previous The previous exception used for 
the exception chaining.
         */
        public function __construct( $messageSpec, $code = 0, $previous = null 
) {
diff --git a/includes/gallery/ImageGalleryBase.php 
b/includes/gallery/ImageGalleryBase.php
index eeb8a8f..80fd22e 100644
--- a/includes/gallery/ImageGalleryBase.php
+++ b/includes/gallery/ImageGalleryBase.php
@@ -177,7 +177,7 @@
        /**
         * Set the caption (as plain text)
         *
-        * @param string $caption Caption
+        * @param string $caption
         */
        function setCaption( $caption ) {
                $this->mCaption = htmlspecialchars( $caption );
@@ -186,7 +186,7 @@
        /**
         * Set the caption (as HTML)
         *
-        * @param string $caption Caption
+        * @param string $caption
         */
        public function setCaptionHtml( $caption ) {
                $this->mCaption = $caption;
diff --git a/includes/installer/PostgresInstaller.php 
b/includes/installer/PostgresInstaller.php
index cb1b47e..21d83d2 100644
--- a/includes/installer/PostgresInstaller.php
+++ b/includes/installer/PostgresInstaller.php
@@ -152,7 +152,7 @@
        /**
         * Open a PG connection with given parameters
         * @param string $user User name
-        * @param string $password Password
+        * @param string $password
         * @param string $dbName Database name
         * @param string $schema Database schema
         * @return Status
diff --git a/includes/libs/IEUrlExtension.php b/includes/libs/IEUrlExtension.php
index 2d1c58b..0d969fb 100644
--- a/includes/libs/IEUrlExtension.php
+++ b/includes/libs/IEUrlExtension.php
@@ -186,7 +186,7 @@
         * - if we find a possible extension followed by a dot or another 
illegal
         *   character, we ignore it and continue searching
         *
-        * @param string $url URL
+        * @param string $url
         * @return mixed Detected extension (string), or false if none found
         */
        public static function findIE6Extension( $url ) {
diff --git a/includes/libs/StatusValue.php b/includes/libs/StatusValue.php
index f9dcc1b..6f348c2 100644
--- a/includes/libs/StatusValue.php
+++ b/includes/libs/StatusValue.php
@@ -214,7 +214,7 @@
        /**
         * Merge another status object into this one
         *
-        * @param StatusValue $other Other StatusValue object
+        * @param StatusValue $other
         * @param bool $overwriteValue Whether to override the "value" member
         */
        public function merge( $other, $overwriteValue = false ) {
diff --git a/includes/libs/mime/XmlTypeCheck.php 
b/includes/libs/mime/XmlTypeCheck.php
index 9761108..648fb67 100644
--- a/includes/libs/mime/XmlTypeCheck.php
+++ b/includes/libs/mime/XmlTypeCheck.php
@@ -294,7 +294,7 @@
 
        /**
         * @param string $name element or attribute name, maybe with a full or 
short prefix
-        * @param string $namespaceURI the namespaceURI
+        * @param string $namespaceURI
         * @return string the name prefixed with namespaceURI
         */
        private function expandNS( $name, $namespaceURI ) {
diff --git a/includes/libs/objectcache/MemcachedClient.php 
b/includes/libs/objectcache/MemcachedClient.php
index 5cb49a9..91863b2 100644
--- a/includes/libs/objectcache/MemcachedClient.php
+++ b/includes/libs/objectcache/MemcachedClient.php
@@ -363,7 +363,7 @@
        /**
         * Changes the TTL on a key from the server to $time
         *
-        * @param string $key Key
+        * @param string $key
         * @param int $time TTL in seconds
         *
         * @return bool True on success, false on failure
diff --git a/includes/libs/rdbms/TransactionProfiler.php 
b/includes/libs/rdbms/TransactionProfiler.php
index 57a12a4..a828cd3 100644
--- a/includes/libs/rdbms/TransactionProfiler.php
+++ b/includes/libs/rdbms/TransactionProfiler.php
@@ -82,7 +82,7 @@
        }
 
        /**
-        * @param bool $value New value
+        * @param bool $value
         * @return bool Old value
         * @since 1.28
         */
diff --git a/includes/logging/LogEventsList.php 
b/includes/logging/LogEventsList.php
index 00d3bd3..c58975a 100644
--- a/includes/logging/LogEventsList.php
+++ b/includes/logging/LogEventsList.php
@@ -98,8 +98,8 @@
         * @param string $user
         * @param string $page
         * @param string $pattern
-        * @param int $year Year
-        * @param int $month Month
+        * @param int $year
+        * @param int $month
         * @param array $filter
         * @param string $tagFilter Tag to select by default
         * @param string $action
@@ -426,7 +426,7 @@
        }
 
        /**
-        * @param stdClass $row Row
+        * @param stdClass $row
         * @return string
         */
        private function getShowHideLinks( $row ) {
@@ -496,7 +496,7 @@
        }
 
        /**
-        * @param stdClass $row Row
+        * @param stdClass $row
         * @param string|array $type
         * @param string|array $action
         * @param string $right
@@ -521,7 +521,7 @@
         * Determine if the current user is allowed to view a particular
         * field of this log row, if it's marked as deleted.
         *
-        * @param stdClass $row Row
+        * @param stdClass $row
         * @param int $field
         * @param User $user User to check, or null to use $wgUser
         * @return bool
@@ -558,7 +558,7 @@
        }
 
        /**
-        * @param stdClass $row Row
+        * @param stdClass $row
         * @param int $field One of DELETED_* bitfield constants
         * @return bool
         */
diff --git a/includes/logging/LogPage.php b/includes/logging/LogPage.php
index e421209..77d9aa2 100644
--- a/includes/logging/LogPage.php
+++ b/includes/logging/LogPage.php
@@ -319,7 +319,7 @@
         *
         * @param string $action One of '', 'block', 'protect', 'rights', 
'delete',
         *   'upload', 'move', 'move_redir'
-        * @param Title $target Title object
+        * @param Title $target
         * @param string $comment Description associated
         * @param array $params Parameters passed later to wfMessage function
         * @param null|int|User $doer The user doing the action. null for 
$wgUser
diff --git a/includes/media/BitmapMetadataHandler.php 
b/includes/media/BitmapMetadataHandler.php
index 2ed5db3..9e0fc3d 100644
--- a/includes/media/BitmapMetadataHandler.php
+++ b/includes/media/BitmapMetadataHandler.php
@@ -292,7 +292,7 @@
         * Read the first 2 bytes of a tiff file to figure out
         * Little Endian or Big Endian. Needed for exif stuff.
         *
-        * @param string $filename The filename
+        * @param string $filename
         * @return string 'BE' or 'LE' or false
         */
        static function getTiffByteOrder( $filename ) {
diff --git a/includes/media/IPTC.php b/includes/media/IPTC.php
index 343adc2..894043a 100644
--- a/includes/media/IPTC.php
+++ b/includes/media/IPTC.php
@@ -353,20 +353,20 @@
         * @todo Potentially this should also capture the timezone offset.
         * @param array $date The date tag
         * @param array $time The time tag
-        * @param string $c The charset
+        * @param string $charset
         * @return string Date in EXIF format.
         */
-       private static function timeHelper( $date, $time, $c ) {
+       private static function timeHelper( $date, $time, $charset ) {
                if ( count( $date ) === 1 ) {
                        // the standard says this should always be 1
                        // just double checking.
-                       list( $date ) = self::convIPTC( $date, $c );
+                       list( $date ) = self::convIPTC( $date, $charset );
                } else {
                        return null;
                }
 
                if ( count( $time ) === 1 ) {
-                       list( $time ) = self::convIPTC( $time, $c );
+                       list( $time ) = self::convIPTC( $time, $charset );
                        $dateOnly = false;
                } else {
                        $time = '000000+0000'; // placeholder
@@ -420,7 +420,7 @@
        /**
         * Helper function to convert charset for iptc values.
         * @param string|array $data The iptc string
-        * @param string $charset The charset
+        * @param string $charset
         *
         * @return string|array
         */
@@ -439,7 +439,7 @@
        /**
         * Helper function of a helper function to convert charset for iptc 
values.
         * @param string|array $data The IPTC string
-        * @param string $charset The charset
+        * @param string $charset
         *
         * @return string
         */
diff --git a/includes/media/MediaHandler.php b/includes/media/MediaHandler.php
index 8551a12..5dca24b 100644
--- a/includes/media/MediaHandler.php
+++ b/includes/media/MediaHandler.php
@@ -255,7 +255,7 @@
         * Get a MediaTransformOutput object representing the transformed 
output. Does not
         * actually do the transform.
         *
-        * @param File $image The image object
+        * @param File $image
         * @param string $dstPath Filesystem destination path
         * @param string $dstUrl Destination URL to use in output HTML
         * @param array $params Arbitrary set of parameters validated by 
$this->validateParam()
@@ -269,7 +269,7 @@
         * Get a MediaTransformOutput object representing the transformed 
output. Does the
         * transform unless $flags contains self::TRANSFORM_LATER.
         *
-        * @param File $image The image object
+        * @param File $image
         * @param string $dstPath Filesystem destination path
         * @param string $dstUrl Destination URL to use in output HTML
         * @param array $params Arbitrary set of parameters validated by 
$this->validateParam()
@@ -497,7 +497,7 @@
         *
         * This is used by the media handlers that use the FormatMetadata class
         *
-        * @param array $metadataArray Metadata array
+        * @param array $metadataArray
         * @param bool|IContextSource $context Context to use (optional)
         * @return array Array for use displaying metadata.
         */
diff --git a/includes/media/WebP.php b/includes/media/WebP.php
index e23989d..e57377f 100644
--- a/includes/media/WebP.php
+++ b/includes/media/WebP.php
@@ -154,7 +154,7 @@
 
        /**
         * Decodes a lossy chunk header
-        * @param string $header Header string
+        * @param string $header
         * @return bool|array See WebPHandler::decodeHeader
         */
        protected static function decodeLossyChunkHeader( $header ) {
@@ -180,7 +180,7 @@
 
        /**
         * Decodes a lossless chunk header
-        * @param string $header Header string
+        * @param string $header
         * @return bool|array See WebPHandler::decodeHeader
         */
        public static function decodeLosslessChunkHeader( $header ) {
@@ -205,7 +205,7 @@
 
        /**
         * Decodes an extended chunk header
-        * @param string $header Header string
+        * @param string $header
         * @return bool|array See WebPHandler::decodeHeader
         */
        public static function decodeExtendedChunkHeader( $header ) {
diff --git a/includes/media/XCF.php b/includes/media/XCF.php
index 3587eba..1b6c4c8 100644
--- a/includes/media/XCF.php
+++ b/includes/media/XCF.php
@@ -151,7 +151,7 @@
         *
         * @param File|FSFile $file The image object, or false if there isn't 
one.
         *   Warning, FSFile::getPropsFromPath might pass an (object)array() 
instead (!)
-        * @param string $filename The filename
+        * @param string $filename
         * @return string
         */
        public function getMetadata( $file, $filename ) {
diff --git a/includes/parser/Parser.php b/includes/parser/Parser.php
index 078de3c..84798a0 100644
--- a/includes/parser/Parser.php
+++ b/includes/parser/Parser.php
@@ -4683,7 +4683,7 @@
         * Wrapper for preprocess()
         *
         * @param string $text The text to preprocess
-        * @param ParserOptions $options Options
+        * @param ParserOptions $options
         * @param Title|null $title Title object or null to use $wgTitle
         * @return string
         */
@@ -5976,7 +5976,7 @@
        /**
         * Remove any strip markers found in the given text.
         *
-        * @param string $text Input string
+        * @param string $text
         * @return string
         */
        public function killMarkers( $text ) {
diff --git a/includes/parser/StripState.php b/includes/parser/StripState.php
index 4ed176c..298aad3 100644
--- a/includes/parser/StripState.php
+++ b/includes/parser/StripState.php
@@ -233,7 +233,7 @@
        /**
         * Remove any strip markers found in the given text.
         *
-        * @param string $text Input string
+        * @param string $text
         * @return string
         */
        public function killMarkers( $text ) {
diff --git a/includes/resourceloader/ResourceLoaderModule.php 
b/includes/resourceloader/ResourceLoaderModule.php
index b3c1cd1..aaa2767 100644
--- a/includes/resourceloader/ResourceLoaderModule.php
+++ b/includes/resourceloader/ResourceLoaderModule.php
@@ -110,7 +110,7 @@
         * Set this module's name. This is called by ResourceLoader::register()
         * when registering the module. Other code should not call this.
         *
-        * @param string $name Name
+        * @param string $name
         */
        public function setName( $name ) {
                $this->name = $name;
@@ -932,7 +932,7 @@
         * Get this module's last modification timestamp for a given context.
         *
         * @deprecated since 1.26 Use getDefinitionSummary() instead
-        * @param ResourceLoaderContext $context Context object
+        * @param ResourceLoaderContext $context
         * @return int|null UNIX timestamp
         */
        public function getModifiedTime( ResourceLoaderContext $context ) {
diff --git a/includes/revisiondelete/RevDelItem.php 
b/includes/revisiondelete/RevDelItem.php
index bf97bd4..4762085 100644
--- a/includes/revisiondelete/RevDelItem.php
+++ b/includes/revisiondelete/RevDelItem.php
@@ -57,7 +57,7 @@
        /**
         * Get the return information about the revision for the API
         * @since 1.23
-        * @param ApiResult $result API result object
+        * @param ApiResult $result
         * @return array Data for the API result
         */
        abstract public function getApiData( ApiResult $result );
diff --git a/includes/search/SearchExactMatchRescorer.php 
b/includes/search/SearchExactMatchRescorer.php
index 0e99ba9..c99db6e 100644
--- a/includes/search/SearchExactMatchRescorer.php
+++ b/includes/search/SearchExactMatchRescorer.php
@@ -34,7 +34,7 @@
         * may sort based on other algorithms that may cause the exact title 
match
         * to not be in the results or be lower down the list.
         * @param string $search the query
-        * @param int[] $namespaces the namespaces
+        * @param int[] $namespaces
         * @param string[] $srchres results
         * @param int $limit the max number of results to return
         * @return string[] munged results
@@ -96,7 +96,7 @@
        }
 
        /**
-        * @param string[] $titles as strings
+        * @param string[] $titles
         * @return array redirect target prefixedText to index of title in 
titles
         *   that is a redirect to it.
         */
diff --git a/includes/session/SessionBackend.php 
b/includes/session/SessionBackend.php
index d37b73b..44806ed 100644
--- a/includes/session/SessionBackend.php
+++ b/includes/session/SessionBackend.php
@@ -97,7 +97,7 @@
        private $shutdown = false;
 
        /**
-        * @param SessionId $id Session ID object
+        * @param SessionId $id
         * @param SessionInfo $info Session info to populate from
         * @param CachedBagOStuff $store Backend data store
         * @param LoggerInterface $logger
diff --git a/includes/specialpage/ChangesListSpecialPage.php 
b/includes/specialpage/ChangesListSpecialPage.php
index 303184d..282d764 100644
--- a/includes/specialpage/ChangesListSpecialPage.php
+++ b/includes/specialpage/ChangesListSpecialPage.php
@@ -1812,7 +1812,7 @@
         *
         * @since 1.31
         * @param Config $config
-        * @param User $user User object
+        * @param User $user
         * @return bool
         */
        public static function checkStructuredFilterUiEnabled( Config $config, 
User $user ) {
diff --git a/includes/specials/SpecialRecentchanges.php 
b/includes/specials/SpecialRecentchanges.php
index 32204f8..2461754 100644
--- a/includes/specials/SpecialRecentchanges.php
+++ b/includes/specials/SpecialRecentchanges.php
@@ -825,7 +825,7 @@
        /**
         * Makes change an option link which carries all the other options
         *
-        * @param string $title Title
+        * @param string $title
         * @param array $override Options to override
         * @param array $options Current options
         * @param bool $active Whether to show the link in bold
diff --git a/includes/specials/SpecialUploadStash.php 
b/includes/specials/SpecialUploadStash.php
index 8cdfb87..c8b1578 100644
--- a/includes/specials/SpecialUploadStash.php
+++ b/includes/specials/SpecialUploadStash.php
@@ -315,7 +315,7 @@
        /**
         * Output HTTP response of raw content
         * Side effect: writes HTTP response to STDOUT.
-        * @param string $content Content
+        * @param string $content
         * @param string $contentType MIME type
         * @throws SpecialUploadStashTooLargeException
         * @return bool
diff --git a/includes/specials/pagers/UsersPager.php 
b/includes/specials/pagers/UsersPager.php
index 45d9a7f..4efe92d 100644
--- a/includes/specials/pagers/UsersPager.php
+++ b/includes/specials/pagers/UsersPager.php
@@ -407,7 +407,7 @@
         * Format a link to a group description page
         *
         * @param string|UserGroupMembership $group Group name or 
UserGroupMembership object
-        * @param string $username Username
+        * @param string $username
         * @return string
         */
        protected function buildGroupLink( $group, $username ) {
diff --git a/includes/user/User.php b/includes/user/User.php
index 0d8ef89..8ac9a61 100644
--- a/includes/user/User.php
+++ b/includes/user/User.php
@@ -4583,7 +4583,7 @@
         * (T8957 with Gmail and Internet Explorer).
         *
         * @param string $page Special page
-        * @param string $token Token
+        * @param string $token
         * @return string Formatted URL
         */
        protected function getTokenUrl( $page, $token ) {
diff --git a/maintenance/generateSitemap.php b/maintenance/generateSitemap.php
index bed84a8..f568ddb 100644
--- a/maintenance/generateSitemap.php
+++ b/maintenance/generateSitemap.php
@@ -440,8 +440,8 @@
        /**
         * Get a sitemap filename
         *
-        * @param int $namespace The namespace
-        * @param int $count The count
+        * @param int $namespace
+        * @param int $count
         * @return string
         */
        function sitemapFilename( $namespace, $count ) {
diff --git a/maintenance/importImages.php b/maintenance/importImages.php
index d3aa280..a72ec67 100644
--- a/maintenance/importImages.php
+++ b/maintenance/importImages.php
@@ -440,7 +440,7 @@
        /**
         * Split a filename into filename and extension
         *
-        * @param string $filename Filename
+        * @param string $filename
         * @return array
         */
        private function splitFilename( $filename ) {
diff --git a/maintenance/sql.php b/maintenance/sql.php
index 8e276e7..a67b28e 100644
--- a/maintenance/sql.php
+++ b/maintenance/sql.php
@@ -167,7 +167,7 @@
 
        /**
         * Print the results, callback for $db->sourceStream()
-        * @param ResultWrapper|bool $res The results object
+        * @param ResultWrapper|bool $res
         * @param IDatabase $db
         */
        public function sqlPrintResult( $res, $db ) {
diff --git 
a/tests/phpunit/includes/auth/LegacyHookPreAuthenticationProviderTest.php 
b/tests/phpunit/includes/auth/LegacyHookPreAuthenticationProviderTest.php
index a4b980f..0fdb08c 100644
--- a/tests/phpunit/includes/auth/LegacyHookPreAuthenticationProviderTest.php
+++ b/tests/phpunit/includes/auth/LegacyHookPreAuthenticationProviderTest.php
@@ -282,7 +282,7 @@
         * @dataProvider provideTestForAccountCreation
         * @param string $msg
         * @param Status|null $status
-        * @param StatusValue $result Result
+        * @param StatusValue $result
         */
        public function testTestForAccountCreation( $msg, $status, $result ) {
                $this->hook( 'AbortNewAccount', $this->once() )
diff --git a/tests/phpunit/includes/collation/CollationTest.php 
b/tests/phpunit/includes/collation/CollationTest.php
index 25911a7..b92e651 100644
--- a/tests/phpunit/includes/collation/CollationTest.php
+++ b/tests/phpunit/includes/collation/CollationTest.php
@@ -21,7 +21,7 @@
         * code makes this assumption.
         *
         * @param string $lang Language code for collator
-        * @param string $base Base string
+        * @param string $base
         * @param string $extended String containing base as a prefix.
         *
         * @dataProvider prefixDataProvider
diff --git a/tests/phpunit/includes/session/TestBagOStuff.php 
b/tests/phpunit/includes/session/TestBagOStuff.php
index fd02a2e..bac2088 100644
--- a/tests/phpunit/includes/session/TestBagOStuff.php
+++ b/tests/phpunit/includes/session/TestBagOStuff.php
@@ -14,7 +14,7 @@
        /**
         * @param string $id Session ID
         * @param array $data Session data
-        * @param int $expiry Expiry
+        * @param int $expiry
         * @param User $user User for metadata
         */
        public function setSessionData( $id, array $data, $expiry = 0, User 
$user = null ) {
@@ -24,7 +24,7 @@
        /**
         * @param string $id Session ID
         * @param array $metadata Session metadata
-        * @param int $expiry Expiry
+        * @param int $expiry
         */
        public function setSessionMeta( $id, array $metadata, $expiry = 0 ) {
                $this->setSession( $id, [ 'metadata' => $metadata ], $expiry );
@@ -33,7 +33,7 @@
        /**
         * @param string $id Session ID
         * @param array $blob Session metadata and data
-        * @param int $expiry Expiry
+        * @param int $expiry
         * @param User $user User for metadata
         */
        public function setSession( $id, array $blob, $expiry = 0, User $user = 
null ) {
@@ -54,7 +54,7 @@
        /**
         * @param string $id Session ID
         * @param array|mixed $blob Session metadata and data
-        * @param int $expiry Expiry
+        * @param int $expiry
         */
        public function setRawSession( $id, $blob, $expiry = 0 ) {
                if ( $expiry <= 0 ) {
diff --git a/tests/phpunit/includes/session/TestUtils.php 
b/tests/phpunit/includes/session/TestUtils.php
index af29d6b..5db1ad0 100644
--- a/tests/phpunit/includes/session/TestUtils.php
+++ b/tests/phpunit/includes/session/TestUtils.php
@@ -79,7 +79,7 @@
         * If you need a Session for testing but don't want to create a backend 
to
         * construct one, use this.
         * @param object $backend Object to serve as the SessionBackend
-        * @param int $index Index
+        * @param int $index
         * @param LoggerInterface $logger
         * @return Session
         */
diff --git a/tests/phpunit/mocks/content/DummyContentForTesting.php 
b/tests/phpunit/mocks/content/DummyContentForTesting.php
index 4392964..e8259d3 100644
--- a/tests/phpunit/mocks/content/DummyContentForTesting.php
+++ b/tests/phpunit/mocks/content/DummyContentForTesting.php
@@ -112,7 +112,7 @@
         *
         * @param Title $title Context title for parsing
         * @param int|null $revId Revision ID (for {{REVISIONID}})
-        * @param ParserOptions $options Parser options
+        * @param ParserOptions $options
         * @param bool $generateHtml Whether or not to generate HTML
         * @param ParserOutput &$output The output object to fill (reference).
         */
diff --git a/tests/phpunit/mocks/content/DummyNonTextContent.php 
b/tests/phpunit/mocks/content/DummyNonTextContent.php
index afc1a4a..91bb186 100644
--- a/tests/phpunit/mocks/content/DummyNonTextContent.php
+++ b/tests/phpunit/mocks/content/DummyNonTextContent.php
@@ -110,7 +110,7 @@
         *
         * @param Title $title Context title for parsing
         * @param int|null $revId Revision ID (for {{REVISIONID}})
-        * @param ParserOptions $options Parser options
+        * @param ParserOptions $options
         * @param bool $generateHtml Whether or not to generate HTML
         * @param ParserOutput &$output The output object to fill (reference).
         */

diff --git a/includes/cache/MessageCache.php b/includes/cache/MessageCache.php
index d6e9b74..4872186 100644
--- a/includes/cache/MessageCache.php
+++ b/includes/cache/MessageCache.php
@@ -156,22 +156,22 @@
        }
 
        /**
         * @param WANObjectCache $wanCache WAN cache instance
         * @param BagOStuff $clusterCache Cluster cache instance
         * @param BagOStuff $srvCache Server cache instance
         * @param bool $useDB Whether to look for message overrides (e.g. 
MediaWiki: pages)
         * @param int $expiry Lifetime for cache. @see $mExpiry.
         */
        public function __construct(
                WANObjectCache $wanCache,
                BagOStuff $clusterCache,
-               BagOStuff $srvCache,
+               BagOStuff $serverCache,
                $useDB,
                $expiry
        ) {
                $this->wanCache = $wanCache;
                $this->clusterCache = $clusterCache;
-               $this->srvCache = $srvCache;
+               $this->srvCache = $serverCache;
 
                $this->mDisable = !$useDB;
                $this->mExpiry = $expiry;
@@ -156,22 +156,22 @@
 
        /**
-        * @param WANObjectCache $wanCache WAN cache instance
-        * @param BagOStuff $clusterCache Cluster cache instance
-        * @param BagOStuff $srvCache Server cache instance
+        * @param WANObjectCache $wanCache
+        * @param BagOStuff $clusterCache
+        * @param BagOStuff $serverCache
         * @param bool $useDB Whether to look for message overrides (e.g. 
MediaWiki: pages)
-- 
To view, visit https://gerrit.wikimedia.org/r/400582
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Iee70aad681b3385e9af282d5581c10addbb91ac4
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Thiemo Kreuz (WMDE) <thiemo.kr...@wikimedia.de>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to